==> oddmuse-1.754.tar.gz: oddmuse-1.754/romanian-utf8.pl <==
# UTF-8 encoded Romanian translation file for use with Oddmuse
#
# Copyright (c) 2005  Victor Osadci <vic_site@xhtml.md>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
$ModulesDescription .= '<p>$Id: romanian-utf8.pl,v 1.7 2006/08/18 22:46:10 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Citirea nu este permisă: utilizatorul, ip-ul sau reţeaua este blocată.
%s calls

Could not create %s
Nu am putut crea %s
Invalid UserName %s: not saved.
Nume incorect %s: nu sa salvat.
UserName must be 50 characters or less: not saved
Lungimea numelui este de maximum 50 de caractere: nu sa salvat
This page contains an uploaded file:

Recursive include of %s!

Clear Cache

Main lock obtained.

Main lock released.

Comments on this page
Comentarii la această pagină.
XML::RSS is not available on this system.
XML::RSS nu este disponibil pe acest sistem.
diff
diferenţe
history
istoric
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.
Nici un element găsit în %s.
 . . . . 

Click to edit this page
Editează această pagină
image
imagine
download

CGI Internal error: %s

Invalid action parameter %s

Invalid URL.
URL incorect.
Page name is missing
Lipseşte numele paginii.
Page name is too long: %s
Numele paginii este prea lung: %s
Invalid Page %s (must not end with .db)

Invalid Page %s (must not end with .lck)

Invalid Page %s

Preview:
Previzualizare:
Preview only, not yet saved
Previzualizare, pagina nu a fost încă salvată
Please go on to %s.

No updates since %s
Nici o modificare de la %s
Updates since %s
Modificări de la %s
Updates in the last %s days
Modificări în ultimele %s zile
Updates in the last %s day
Modificări în ultima %s zi
for %s only
numai pentru %s
List latest change per page only

List all changes
Arată toate modificările
Skip rollbacks

Include rollbacks

List only major changes
Arată numai modificările majore
Include minor changes
Include modificările minore
%s days
%s zile
List later changes
Arată modificările ulterioare
Filters
Filtre
Title:
Titlu:
Title and Body:
Titlu şi Conţinut:
Username:
Utilizator:
Host:
Adresă:
Language:
Limbă:
Go!
Du-te!
(minor)
(minoră)
rollback
restaurează
new
nou
from %s
de la %s
This page is too big to send over RSS.

History of %s
Istorcul %s
Compare
Compară
Deleted

Mark this page for deletion

No other revisions available

current

Revision %s
Revizia %s
Contributors to %s

Missing target for rollback.

Target for rollback is too far back.

Rolling back changes

The two revisions are the same.

Editing not allowed for %s.
Editarea nu este permisă pentru %s
Rollback to %s

%s rolled back

to %s

Index of all pages
Indexul tuturor paginilor
Wiki Version
Versiunea Wiki
Unlock Wiki
Deblochează Wiki
Password
Parola
Run maintenance

Unlock site
Deblochează site-ul
Lock site
Blochează site-ul
Install CSS

Unlock %s
Deblochează %s
Lock %s
Blochează %s
Administration
Administrare
Actions:
Acţiuni:
Important pages:
Pagini importante:
To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Acasă]
redirected from %s
redirecţionat de la %s
Click to search for references to this page
Caută referinţe la această pagină
Cookie: 

Warning
Atenţie
Database is stored in temporary directory %s
Baza de date este păstrată în directorul temporar %s
%s seconds
%s secunde
The same page on other sites:
Aceiaşi pagină pe alte site-uri:
EditNearLinks

Last edited
Modificat pe
Edited
Modificat pe
by %s
de către %s
(diff)
(diferenţe)
Edit revision %s of this page
Editează revizia %s a acestei pagini
Edit this page
Editează această pagină
e

This page is read-only
Această pagină este numai pentru citire
View other revisions
Vezi alte revizii
View current revision
Vezi revizia curentă
View all changes
Vezi toate modificările
View contributors

Homepage URL:

s

Save
Salvează
p

Preview
Previzualizare
Search:
Caută:
f

Replace:
Înlocuieşte:
Validate HTML
HTML Valid
Validate CSS
CSS Valid
Last edit

Difference between revision %1 and %2
Diferenţe (între revizia %1 şi %2)
revision %s
revizia %s
current revision
revizia curentă
Last major edit (%s)

later minor edits

No diff available.
Nici o diferenţă disponibilă.
Old revision:
Revizia veche:
Changed:
Modificat:
Deleted:

Added:
Adăugat:
to
ca
Revision %s not available
Revizia %s nu este disponibilă
showing current revision instead

Showing revision %s

Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Cannot create %s

Could not get %s lock

The lock was created %s.

This operation may take several seconds...

Forced unlock of %s lock.

No unlock required.

%s hours ago
cu %s ore în urmă
1 hour ago
cu 1 oră în urmă
%s minutes ago
cu %s minute în urmă
1 minute ago
cu 1 minut în urmă
%s seconds ago
cu %s secunde în urmă
1 second ago
cu 1 secundă în urmă
just now
acum
Edit Denied
Editarea nu este permisă
Editing not allowed: user, ip, or network is blocked.
Editarea nu este permisă: utilizatorul, ip-ul sau reţeaua este blocată.
Contact the wiki administrator for more information.
Contactaţi administratorul pentru mai multă informaţie.
The rule %s matched for you.

See %s for more information.
Vezi %s pentru mai multă informaţie.
Editing not allowed: %s is read-only.
Editarea nu este permisă: %s este numai pentru citire.
Only administrators can upload files.
Numai administratorii pot adăuga fişiere.
Editing revision %s of
Editarea reviziei %s a
Editing %s
Editarea paginii %s
Editing old revision %s.
Editarea reviziei vechi %s.
Saving this page will replace the latest revision with this text.
Salvarea acestei pagini va înlocui cea mai recentă revizie cu acest text.
Summary:
Sumar:
This change is a minor edit.
Această modificare este una minoră.
Replace this file with text
Înlocuieşte acest fişier cu text
Replace this text with a file
Înlocuieşte acest text cu un fişier
File to upload: 
Fişier pentru adăugare.
Files of type %s are not allowed.
Fişierele de tipul %s nu sunt permise.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.

You are currently an administrator on this site.
Sunteţi administrator pe acest site.
You are currently an editor on this site.
Sunteţi editor pe acest site.
You are a normal user on this site.
Sunteţi un utilizator obişnuit pe acest site.
Your password does not match any of the  administrator or editor passwords.
Parola dumneavoastră nu corespunde nici unei parole de administrator sau editor.
Password:
Parola:
This site does not use admin or editor passwords.
Acest site nu foloseşte parole pentru administrare sau editare.
This operation is restricted to site editors only...
Această operaţie este permisă numai editorilor...
This operation is restricted to administrators only...
Această operaţie este permisă numai administratorilor...
SampleUndefinedPage

Sample_Undefined_Page

Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)
(pentru %s)
Filter:
Filtru:
%s pages found.
%s pagini găsite.
Replaced: %s
Înlocuiri: %s
Search for: %s
Căutare: %s
View changes for these pages
Vezi modificările acestor pagini
Search sites on the %s as well

and
şi
or
sau
Fetching results from %s:

Near pages:

last updated
editată pe
by
de către
Transfer Error: %s
Eroare la Transfer: %s
Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous
Anonim
Cannot delete the index file %s.
Nu am putut şterge fişierul index %s.
Please check the directory permissions.

Your changes were not saved.
Modificările nu au fost salvate.
Could not get a lock to merge!

you

ancestor

other

Run Maintenance

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted
şters
Moving part of the %s log file.

Could not open %s log file

Error was
Eroarea a fost
Note: This error is normal if no changes have been made.

Moving %s log entries.

Getting page index file for %s.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s
Prea multe conexiuni de la %s
Please do not fetch more than %1 pages in %2 seconds.
Vă rugăm să nu accesaţi mai mult de %1 pagini în %2 secunde.
Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists
pagina %s de asemenea există
Copy one of the following stylesheets to %s:

Deleting %s
Se şterge %s
Deleted %s
%s a fost şters
Renaming %1 to %2.
Redenumesc %1 în %2
The page %s does not exist
Pagina %s nu există
The page %s already exists
Pagina %s există deja
Cannot rename %1 to %2
Nu am putut redenumi %1 în %2
Renamed to %s
Redenumit ca %s
Renamed from %s
Redenumit de la %s
Renamed %1 to %2.
Redenumit %1 ca %2
Immediately delete %s

Rename %s to:
Redenumeşte %s ca:
Learn more...

Complete Content

The main page is %s.
Pagina principală este %s.
Cannot highlight the language %s.

Recent Visitors
Vizitatori Recenţi
some action
o acţiune
was here
a fost aici
and read
şi a citit
Illegal year value: Use 0001-9999

The match parameter is missing.

Page Collection for %s

Previous
Precedent
Next
Următor
Calendar %s

Su

Mo

Tu

We

Th

Fr

Sa

January

February

March

April

May

June

July

August

September

October

November

December

Clustermap

Pages without a Cluster

Comments on 
Comentarii la
Comment on 
Comentariu la
Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Add Comment
Adaugă Comentariu
ordinary changes

Footnotes:
Note de subsol:
Could not find %1.html template in %2

Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index

Languages:
Limbi:
Show!

Define

Full Link List

Template without parameters

The template %s is either empty or does not exist.

 -- defined on %s

Local names defined on %1: %2

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.
Parolele nu se potrivesc.
The password must be at least %s characters.
Lungimea parolei trebuie să fie de cel puţin %s caractere.
That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.
Numele şi/sau parola sunt greşite.
Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Login

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

%s is not a legal name for a namespace

Clearing Cache

Done.
Gata.
Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List

Trail: 
Pagini recente: 
None

Type
Tip
Permalink to "%s"

There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Portrait

Publish %s

No target wiki was specified in the config file.

The target wiki was misconfigured.

You did not answer correctly.

To save this page you must answer this question:

All Referrers

Referrers

Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

 ... 

Search term missing.

Result pages: 

(%s results)
(%s rezultate)
Tags:

Tags: %s.

No tags

Slideshow:%s

Static Copy

Back to %s
Înapoi la %s
Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add
Adaugă
URL parameter is missing.

Add to %s thread

Below:

URL:

Name:
Nume:
Failed to remove %s

Contents
Conţinut
This page is a translation of %s. 
Această pagină este o traducere a %s.
The translation is up to date.

The translation is outdated.

The page does not exist.
Pagina nu există.
http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate

http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search

Wanted Pages

%s pages

%s, referenced from:

Upload of %s file

Blog

Matching pages:

New

Edit %s.

Title: 

Tags: 

END_OF_TRANSLATION

==> oddmuse-1.806.tar.gz: oddmuse-1.806/romanian-utf8.pl <==
# UTF-8 encoded Romanian translation file for use with Oddmuse
#
# Copyright (c) 2005  Victor Osadci <vic_site@xhtml.md>
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt .
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
$ModulesDescription .= '<p>$Id: romanian-utf8.pl,v 1.8 2007/08/19 11:42:08 as Exp $</p>';
%Translate = split(/\n/,<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Citirea nu este permisă: utilizatorul, ip-ul sau reţeaua este blocată.
Login

Error

%s calls

Could not create %s
Nu am putut crea %s
Invalid UserName %s: not saved.
Nume incorect %s: nu sa salvat.
UserName must be 50 characters or less: not saved
Lungimea numelui este de maximum 50 de caractere: nu sa salvat
This page contains an uploaded file:

Recursive include of %s!

Clear Cache

Main lock obtained.

Main lock released.

Journal

More...

Comments on this page
Comentarii la această pagină.
XML::RSS is not available on this system.
XML::RSS nu este disponibil pe acest sistem.
diff
diferenţe
history
istoric
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.
Nici un element găsit în %s.
 . . . . 

Click to edit this page
Editează această pagină
CGI Internal error: %s

Invalid action parameter %s

Invalid URL.
URL incorect.
Page name is missing
Lipseşte numele paginii.
Page name is too long: %s
Numele paginii este prea lung: %s
Invalid Page %s (must not end with .db)

Invalid Page %s (must not end with .lck)

Invalid Page %s

Preview:
Previzualizare:
Preview only, not yet saved
Previzualizare, pagina nu a fost încă salvată
Please go on to %s.

All changes for %s

No updates since %s
Nici o modificare de la %s
Updates since %s
Modificări de la %s
Updates in the last %s days
Modificări în ultimele %s zile
Updates in the last %s day
Modificări în ultima %s zi
for %s only
numai pentru %s
List latest change per page only

List all changes
Arată toate modificările
Skip rollbacks

Include rollbacks

List only major changes
Arată numai modificările majore
Include minor changes
Include modificările minore
%s days
%s zile
List later changes
Arată modificările ulterioare
RSS

RSS with pages

RSS with pages and diff

Filters
Filtre
Title:
Titlu:
Title and Body:
Titlu şi Conţinut:
Username:
Utilizator:
Host:
Adresă:
Follow up to:

Language:
Limbă:
Go!
Du-te!
(minor)
(minoră)
rollback
restaurează
new
nou
from %s
de la %s
: 

This page is too big to send over RSS.

History of %s
Istorcul %s
Compare
Compară
Deleted

Mark this page for deletion

No other revisions available

current

Revision %s
Revizia %s
Contributors to %s

Missing target for rollback.

Target for rollback is too far back.

A username is required for ordinary users.

Rolling back changes

The two revisions are the same.

Editing not allowed for %s.
Editarea nu este permisă pentru %s
Rollback to %s

%s rolled back

to %s

Index of all pages
Indexul tuturor paginilor
Wiki Version
Versiunea Wiki
Unlock Wiki
Deblochează Wiki
Password
Parola
Run maintenance

Unlock site
Deblochează site-ul
Lock site
Blochează site-ul
Install CSS

Unlock %s
Deblochează %s
Lock %s
Blochează %s
Administration
Administrare
Actions:
Acţiuni:
Important pages:
Pagini importante:
To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Acasă]
redirected from %s
redirecţionat de la %s
Click to search for references to this page
Caută referinţe la această pagină
Cookie: 

Warning
Atenţie
Database is stored in temporary directory %s
Baza de date este păstrată în directorul temporar %s
%s seconds
%s secunde
The same page on other sites:
Aceiaşi pagină pe alte site-uri:
EditNearLinks

Last edited
Modificat pe
Edited
Modificat pe
by %s
de către %s
(diff)
(diferenţe)
Edit revision %s of this page
Editează revizia %s a acestei pagini
Edit this page
Editează această pagină
e

This page is read-only
Această pagină este numai pentru citire
View other revisions
Vezi alte revizii
View current revision
Vezi revizia curentă
View all changes
Vezi toate modificările
View contributors

Homepage URL:

s

Save
Salvează
p

Preview
Previzualizare
Search:
Caută:
f

Replace:
Înlocuieşte:
Delete

Validate HTML
HTML Valid
Validate CSS
CSS Valid
Last edit

Difference between revision %1 and %2
Diferenţe (între revizia %1 şi %2)
revision %s
revizia %s
current revision
revizia curentă
Last major edit (%s)

later minor edits

No diff available.
Nici o diferenţă disponibilă.
Old revision:
Revizia veche:
Changed:
Modificat:
Deleted:

Added:
Adăugat:
to
ca
Revision %s not available
Revizia %s nu este disponibilă
showing current revision instead

Showing revision %s

Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Cannot create %s

Could not get %s lock

The lock was created %s.

This operation may take several seconds...

Forced unlock of %s lock.

No unlock required.

%s hours ago
cu %s ore în urmă
1 hour ago
cu 1 oră în urmă
%s minutes ago
cu %s minute în urmă
1 minute ago
cu 1 minut în urmă
%s seconds ago
cu %s secunde în urmă
1 second ago
cu 1 secundă în urmă
just now
acum
Edit Denied
Editarea nu este permisă
Editing not allowed: user, ip, or network is blocked.
Editarea nu este permisă: utilizatorul, ip-ul sau reţeaua este blocată.
Contact the wiki administrator for more information.
Contactaţi administratorul pentru mai multă informaţie.
The rule %s matched for you.

See %s for more information.
Vezi %s pentru mai multă informaţie.
Editing not allowed: %s is read-only.
Editarea nu este permisă: %s este numai pentru citire.
Only administrators can upload files.
Numai administratorii pot adăuga fişiere.
Editing revision %s of
Editarea reviziei %s a
Editing %s
Editarea paginii %s
Editing old revision %s.
Editarea reviziei vechi %s.
Saving this page will replace the latest revision with this text.
Salvarea acestei pagini va înlocui cea mai recentă revizie cu acest text.
Summary:
Sumar:
This change is a minor edit.
Această modificare este una minoră.
Cancel

Replace this file with text
Înlocuieşte acest fişier cu text
Replace this text with a file
Înlocuieşte acest text cu un fişier
File to upload: 
Fişier pentru adăugare.
Files of type %s are not allowed.
Fişierele de tipul %s nu sunt permise.
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.

You are currently an administrator on this site.
Sunteţi administrator pe acest site.
You are currently an editor on this site.
Sunteţi editor pe acest site.
You are a normal user on this site.
Sunteţi un utilizator obişnuit pe acest site.
Your password does not match any of the  administrator or editor passwords.
Parola dumneavoastră nu corespunde nici unei parole de administrator sau editor.
Password:
Parola:
This site does not use admin or editor passwords.
Acest site nu foloseşte parole pentru administrare sau editare.
This operation is restricted to site editors only...
Această operaţie este permisă numai editorilor...
This operation is restricted to administrators only...
Această operaţie este permisă numai administratorilor...
SampleUndefinedPage

Sample_Undefined_Page

Rule "%1" matched "%2" on this page.

Reason: %s.

Reason unknown.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)
(pentru %s)
Filter:
Filtru:
%s pages found.
%s pagini găsite.
Replaced: %s
Înlocuiri: %s
Search for: %s
Căutare: %s
View changes for these pages
Vezi modificările acestor pagini
Search sites on the %s as well

and
şi
or
sau
Fetching results from %s:

Near pages:

last updated
editată pe
by
de către
Transfer Error: %s
Eroare la Transfer: %s
Browser reports no file info.

Browser reports no file type.

The page contains banned text.

No changes to be saved.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous
Anonim
Cannot delete the index file %s.
Nu am putut şterge fişierul index %s.
Please check the directory permissions.

Your changes were not saved.
Modificările nu au fost salvate.
Could not get a lock to merge!

you

ancestor

other

Run Maintenance

Maintenance not done.

(Maintenance can only be done once every 12 hours.)

Remove the "maintain" file or wait.

Expiring keep files and deleting pages marked for deletion

not deleted: 

deleted
şters
Moving part of the %s log file.

Could not open %s log file

Error was
Eroarea a fost
Note: This error is normal if no changes have been made.

Moving %s log entries.

Getting page index file for %s.

Set or Remove global edit lock

Edit lock created.

Edit lock removed.

Set or Remove page edit lock

Lock for %s created.

Lock for %s removed.

Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s
Prea multe conexiuni de la %s
Please do not fetch more than %1 pages in %2 seconds.
Vă rugăm să nu accesaţi mai mult de %1 pagini în %2 secunde.
Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists
pagina %s de asemenea există
Copy one of the following stylesheets to %s:

Deleting %s
Se şterge %s
Deleted %s
%s a fost şters
Renaming %1 to %2.
Redenumesc %1 în %2
The page %s does not exist
Pagina %s nu există
The page %s already exists
Pagina %s există deja
Cannot rename %1 to %2
Nu am putut redenumi %1 în %2
Renamed to %s
Redenumit ca %s
Renamed from %s
Redenumit de la %s
Renamed %1 to %2.
Redenumit %1 ca %2
Immediately delete %s

Rename %s to:
Redenumeşte %s ca:
Learn more...

Complete Content

The main page is %s.
Pagina principală este %s.
Archive:

Rebuild BackLink database

Internal Page: 

Pages that link to this page

Cannot highlight the language %s.

Recent Visitors
Vizitatori Recenţi
some action
o acţiune
was here
a fost aici
and read
şi a citit
Illegal year value: Use 0001-9999

The match parameter is missing.

Page Collection for %s

Previous
Precedent
Next
Următor
Calendar %s

Su

Mo

Tu

We

Th

Fr

Sa

January

February

March

April

May

June

July

August

September

October

November

December

set %s

unset %s

Clustermap

Pages without a Cluster

Comments on 
Comentarii la
Comment on 
Comentariu la
Compilation for %s

Compilation tag is missing a regular expression.

List spammed pages

Despamming pages

Spammed pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Recover Draft

No text to save

Draft saved

Draft recovered

No draft available to recover

Save Draft

Draft Cleanup

%1 was last modified %2 and was kept

%1 was last modified %2 and was deleted

Unable to delete draft %s

Add Comment
Adaugă Comentariu
ordinary changes

Matching page names:

Footnotes:
Note de subsol:
Could not find %1.html template in %2

Only Editors are allowed to see this hidden page.

Only Admins are allowed to see this hidden page.

Index

Languages:
Limbi:
Show!

Define

Full Link List

Template without parameters

The template %s is either empty or does not exist.

 -- defined on %s

Local names defined on %1: %2

Register for %s

Please choose a username of the form "FirstLast" using your real name.

The passwords do not match.
Parolele nu se potrivesc.
The password must be at least %s characters.
Lungimea parolei trebuie să fie de cel puţin %s caractere.
That email address is invalid.

The username %s has already been registered.

Your registration for %s has been submitted.

Please allow time for the webmaster to approve your request.

An email has been sent to "%s" with further instructions.

There was an error saving your registration.

An account was created for %s.

Login to %s

Username and/or password are incorrect.
Numele şi/sau parola sunt greşite.
Logged in as %s.

Logout of %s

Logout of %s?

Logged out of %s

You are now logged out.

Register a new account

Logout

Who am I?

Forgot your password?

Change your password

Approve pending registrations

Confirm Registration for %s

%s, your registration has been approved. You can now use your password to login and edit this wiki.

Confirmation failed.  Please email %s for help.

Who Am I?

You are logged in as %s.

You are not logged in.

Reset Password

The password for %s was reset.  It has been emailed to the address on file.

There was an error resetting the password for %s.

The username "%s" does not exist.

Reset Password for %s

Reset Password?

Change Password for %s

Change Password?

Your current password is incorrect.

Your password has been changed.

Approve Pending Registrations for %s

%s has been approved.

There was an error approving %s.

<ul>

<li>%1 - %2</li>

</ul>

There are no pending registrations.

%s is not a legal name for a namespace

 (create locally)

image
imagine
download

Clearing Cache

Done.
Gata.
Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

LocalMap

No page id for action localmap

Requested page %s does not exist

Local Map for %s

view

Self-ban by %s

You have banned your own IP.

Orphan List

Trail: 
Pagini recente: 
None

Type
Tip
Permalink to "%s"

There was an error generating the pdf for %s.  Please report this to webmaster, but do not try to download again as it will not work.

Someone else is generating a pdf for %s.  Please wait a minute and then try again.

Download this page as PDF

Portrait

Publish %s

No target wiki was specified in the config file.

The target wiki was misconfigured.

You did not answer correctly.

Use the back button to return the previous page and try again.

To save this page you must answer this question:

Referrers

All Referrers

Tag

Rebuild index for searching

Tag Cloud

Search::FreeText is not available on this system.

Rebuilding index not done.

(Rebuilding the index can only be done once every 12 hours.)

 ... 

Search term missing.

Result pages: 

(%s results)
(%s rezultate)
Tags:

Tags: %s.

No tags

Slideshow:%s

Index of all small pages

Static Copy

Back to %s
Înapoi la %s
Copy to %1 succeeded: %2.

Copy to %1 failed: %2.

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add
Adaugă
URL parameter is missing.

Add to %s thread

Below:

URL:

Name:
Nume:
Too many instances.  Only %s allowed.

Please try again later. Perhaps somebody is running maintenance or doing a long search. Unfortunately the site has limited resources, and so we must ask you for a bit of patience.

Contents
Conţinut
Create a new page for today

This page is a translation of %s. 
Această pagină este o traducere a %s.
The translation is up to date.

The translation is outdated.

The page does not exist.
Pagina nu există.
http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate

http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search

Wanted Pages

%s pages

%s, referenced from:

Upload of %s file

Blog

Matching pages:

New

Edit %s.

Title: 

Tags: 

END_OF_TRANSLATION
